@@ -31,7 +31,7 @@ use_git <- function(message = "Initial commit") {
 
 #' Add a git hook
 #'
-#' Sets up a git hook using specified script. Creates hook directory if
+#' Sets up a git hook using the specified script. Creates a hook directory if
 #' needed, and sets correct permissions on hook.
 #'
 #' @param hook Hook name. One of "pre-commit", "prepare-commit-msg",
@@ -243,9 +243,9 @@ check_protocol <- function(protocol) {
 #' use_git_remote(name = "upstream", url = upstream_url)
 #' }
 use_git_remote <- function(name = "origin", url, overwrite = FALSE) {
-  stopifnot(is_string(name))
-  stopifnot(is.null(url) || is_string(url))
-  stopifnot(is_true(overwrite) || is_false(overwrite))
+  check_name(name)
+  maybe_name(url)
+  check_bool(overwrite)
 
   remotes <- git_remotes()
   repo <- git_repo()
@@ -323,89 +323,156 @@ git_clean <- function() {
 #' Git/GitHub sitrep
 #'
 #' Get a situation report on your current Git/GitHub status. Useful for
-#' diagnosing problems. [git_vaccinate()] adds some basic R- and RStudio-related
-#' entries to the user-level git ignore file.
+#' diagnosing problems. The default is to report all values; provide values
+#' for `tool` or `scope` to be more specific.
+#'
+#' @param tool Report for __git__, or __github__
+#' @param scope Report globally for the current __user__, or locally for the
+#'   current __project__
+#'
 #' @export
 #' @examples
 #' \dontrun{
+#' # report all
 #' git_sitrep()
+#'
+#' # report git for current user
+#' git_sitrep("git", "user")
 #' }
-git_sitrep <- function() {
+git_sitrep <- function(tool = c("git", "github"),
+                       scope = c("user", "project")) {
+
+  tool <- rlang::arg_match(tool, multiple = TRUE)
+  scope <- rlang::arg_match(scope, multiple = TRUE)
+
   ui_silence(try(proj_get(), silent = TRUE))
 
   # git (global / user) --------------------------------------------------------
-  hd_line("Git config (global)")
-  kv_line("Name", git_cfg_get("user.name", "global"))
-  kv_line("Email", git_cfg_get("user.email", "global"))
-  kv_line("Global (user-level) gitignore file", git_ignore_path("user"))
-  vaccinated <- git_vaccinated()
-  kv_line("Vaccinated", vaccinated)
-  if (!vaccinated) {
-    ui_info("See {ui_code('?git_vaccinate')} to learn more")
-  }
-  kv_line("Default Git protocol", git_protocol())
   init_default_branch <- git_cfg_get("init.defaultBranch", where = "global")
-  kv_line("Default initial branch name", init_default_branch)
+  if ("git" %in% tool && "user" %in% scope) {
+    cli::cli_h3("Git global (user)")
+    git_user_sitrep("user")
+    kv_line("Global (user-level) gitignore file", git_ignore_path("user"))
+    vaccinated <- git_vaccinated()
+    kv_line("Vaccinated", vaccinated)
+    if (!vaccinated) {
+      ui_info("See {ui_code('?git_vaccinate')} to learn more")
+    }
+    kv_line("Default Git protocol", git_protocol())
+    kv_line("Default initial branch name", init_default_branch)
+  }
 
   # github (global / user) -----------------------------------------------------
-  hd_line("GitHub")
   default_gh_host <- get_hosturl(default_api_url())
-  kv_line("Default GitHub host", default_gh_host)
-  pat_sitrep(default_gh_host)
+  if ("github" %in% tool && "user" %in% scope) {
+    cli::cli_h3("GitHub user")
+    kv_line("Default GitHub host", default_gh_host)
+    pat_sitrep(default_gh_host, scope = "user")
+  }
 
   # git and github for active project ------------------------------------------
-  hd_line("Git repo for current project")
+  if (!"project" %in% scope) {
+    return(invisible())
+  }
 
   if (!proj_active()) {
     ui_info("No active usethis project")
     return(invisible())
   }
-  kv_line("Active usethis project", proj_get())
+  cli::cli_h2(glue("Active usethis project: {ui_value(proj_get())}"))
+
   if (!uses_git()) {
     ui_info("Active project is not a Git repo")
     return(invisible())
   }
 
-  # local git config -----------------------------------------------------------
-  if (proj_active() && uses_git()) {
-    local_user <- list(
-      user.name = git_cfg_get("user.name", "local"),
-      user.email = git_cfg_get("user.email", "local")
-    )
-    if (!is.null(local_user$user.name) || !is.null(local_user$user.name)) {
-      ui_info("This repo has a locally configured user")
-      kv_line("Name", local_user$user.name)
-      kv_line("Email", local_user$user.email)
-    }
-  }
-
-  # default branch -------------------------------------------------------------
-  default_branch_sitrep()
-
   # current branch -------------------------------------------------------------
   branch <- tryCatch(git_branch(), error = function(e) NULL)
   tracking_branch <- if (is.null(branch)) NA_character_ else git_branch_tracking()
   # TODO: can't really express with kv_line() helper
   branch <- if (is.null(branch)) "<unset>" else branch
   tracking_branch <- if (is.na(tracking_branch)) "<unset>" else tracking_branch
-  # vertical alignment would make this nicer, but probably not worth it
-  ui_bullet(glue("
-    Current local branch -> remote tracking branch:
-    {ui_value(branch)} -> {ui_value(tracking_branch)}"))
 
+  # local git config -----------------------------------------------------------
+  if ("git" %in% tool) {
+    cli::cli_h3("Git local (project)")
+    git_user_sitrep("project")
+
+    # default branch -------------------------------------------------------------
+    default_branch_sitrep()
+
+    # vertical alignment would make this nicer, but probably not worth it
+    ui_bullet(glue("
+      Current local branch -> remote tracking branch:
+      {ui_value(branch)} -> {ui_value(tracking_branch)}"))
+  }
+
   # GitHub remote config -------------------------------------------------------
-  cfg <- github_remote_config()
-  repo_host <- cfg$host_url
-  if (!is.na(repo_host) && repo_host != default_gh_host) {
-    kv_line("Non-default GitHub host", repo_host)
-    pat_sitrep(repo_host, scold_for_renviron = FALSE)
+  if ("github" %in% tool) {
+    cli::cli_h3("GitHub project")
+
+    cfg <- github_remote_config()
+
+    if (cfg$type == "no_github") {
+      ui_info("Project does not use GitHub")
+      return(invisible())
+    }
+
+    repo_host <- cfg$host_url
+    if (!is.na(repo_host) && repo_host != default_gh_host) {
+      cli::cli_text("Host:")
+      kv_line("Non-default GitHub host", repo_host)
+      pat_sitrep(repo_host, scope = "project", scold_for_renviron = FALSE)
+      cli::cli_text("Project:")
+    }
+
+    purrr::walk(format(cfg), ui_bullet)
   }
 
-  hd_line("GitHub remote configuration")
-  purrr::walk(format(cfg), ui_bullet)
   invisible()
 }
 
+git_user_sitrep <- function(scope = c("user", "project")) {
+  scope <- rlang::arg_match(scope)
+
+  where <- where_from_scope(scope)
+
+  user <- git_user_get(where)
+  user_local <- git_user_get("local")
+
+  if (scope == "project" && !all(map_lgl(user_local, is.null))) {
+    ui_info("This repo has a locally configured user")
+  }
+
+  kv_line("Name", user$name)
+  kv_line("Email", user$email)
+
+  git_user_check(user)
+
+  invisible(NULL)
+}
+
+git_user_check <- function(user) {
+  if (all(map_lgl(user, is.null))) {
+    hint <-
+      'use_git_config(user.name = "<your name>", user.email = "<your email>")'
+    ui_oops(
+      "Git user's name and email are not set. Configure using {ui_code(hint)}."
+    )
+    return(invisible(NULL))
+  }
+
+  if (is.null(user$name)) {
+    hint <- 'use_git_config(user.name = "<your name>")'
+    ui_oops("Git user's name is not set. Configure using {ui_code(hint)}.")
+  }
+
+  if (is.null(user$email)) {
+    hint <- 'use_git_config(user.email = "<your email>")'
+    ui_oops("Git user's email is not set. Configure using {ui_code(hint)}.")
+  }
+}
+
 # TODO: when I really overhaul the UI, determine if I can just re-use the
 # git_default_branch() error messages in the sitrep
 # the main point is converting an error to an "oops" type of message
@@ -439,7 +506,7 @@ default_branch_sitrep <- function() {
 
 #' Vaccinate your global gitignore file
 #'
-#' Adds `.DS_Store`, `.Rproj.user`, `.Rdata`, `.Rhistory`, and `.httr-oauth` to
+#' Adds `.Rproj.user`, `.Rhistory`, `.Rdata`, `.httr-oauth`, `.DS_Store`, and `.quarto` to
 #' your global (a.k.a. user-level) `.gitignore`. This is good practice as it
 #' decreases the chance that you will accidentally leak credentials to GitHub.
 #' `git_vaccinate()` also tries to detect and fix the situation where you have a
@@ -460,7 +527,8 @@ git_vaccinated <- function() {
   if (is.null(path) || !file_exists(path)) {
     return(FALSE)
   }
-  lines <- read_utf8(path)
+  # on Windows, if ~/ is present, take care to expand it the fs way
+  lines <- read_utf8(user_path_prep(path))
   all(git_ignore_lines %in% lines)
 }
 
@@ -469,5 +537,6 @@ git_ignore_lines <- c(
   ".Rhistory",
   ".Rdata",
   ".httr-oauth",
-  ".DS_Store"
+  ".DS_Store",
+  ".quarto"
 )
