@@ -22,12 +22,10 @@
 #'     tidymodels) get some special treatment, in terms of anticipating the
 #'     (eventual) site URL and the use of a pkgdown template.
 #'
-#' `use_pkgdown_travis()` is deprecated; we no longer recommend that you use
-#' Travis-CI.
-#'
 #' @seealso <https://pkgdown.r-lib.org/articles/pkgdown.html#configuration>
-#' @param config_file Path to the pkgdown yaml config file
-#' @param destdir Target directory for pkgdown docs
+#' @param config_file Path to the pkgdown yaml config file, relative to the
+#'  project.
+#' @param destdir Target directory for pkgdown docs.
 #' @export
 use_pkgdown <- function(config_file = "_pkgdown.yml", destdir = "docs") {
   check_is_package("use_pkgdown()")
@@ -78,11 +76,8 @@ use_pkgdown_github_pages <- function() {
   site_url <- tidyverse_url(url = site$html_url, tr = tr)
   use_pkgdown_url(url = site_url, tr = tr)
 
-  if (is_rstudio_pkg()) {
-    ui_done("
-      Adding {ui_value('tidyverse/tidytemplate')} to \\
-      {ui_field('Config/Needs/website')}")
-    use_description_list("Config/Needs/website", "tidyverse/tidytemplate")
+  if (is_posit_pkg()) {
+    proj_desc_field_update("Config/Needs/website", "tidyverse/tidytemplate", append = TRUE)
   }
 }
 
@@ -102,10 +97,7 @@ use_pkgdown_url <- function(url, tr = NULL) {
   }
   write_utf8(config_path, yaml::as.yaml(config))
 
-  ui_done("Adding {ui_value(url)} to {ui_field('URL')} field in DESCRIPTION")
-  desc <- desc::desc(file = proj_get())
-  desc$add_urls(url)
-  desc$write()
+  proj_desc_field_update("URL", url, append = TRUE)
   if (has_package_doc()) {
     ui_todo("
       Run {ui_code('devtools::document()')} to update package-level documentation.")
@@ -189,45 +181,3 @@ pkgdown_url <- function(pedantic = FALSE) {
   }
     NULL
 }
-
-# travis ----
-
-#' @export
-#' @rdname use_pkgdown
-use_pkgdown_travis <- function() {
-  lifecycle::deprecate_soft(
-    when = "2.0.0",
-    what = "usethis::use_pkgdown_travis()",
-    details = 'We recommend `use_github_action("pkgdown")` for new pkgdown setups.'
-  )
-  check_installed("pkgdown")
-  if (!uses_pkgdown()) {
-    ui_stop("
-      Package doesn't use pkgdown.
-      Do you need to call {ui_code('use_pkgdown()')}?")
-  }
-
-  tr <- target_repo(github_get = TRUE)
-
-  use_build_ignore(c("docs/", "pkgdown"))
-  use_git_ignore("docs/")
-  # TODO: suggest git rm -r --cache docs/
-  # Can't currently detect if git known files in that directory
-
-  ui_todo("
-    Set up deploy keys by running {ui_code('travis::use_travis_deploy()')}")
-  ui_todo("Insert the following code in {ui_path('.travis.yml')}")
-  ui_code_block(
-    "
-    before_cache: Rscript -e 'remotes::install_cran(\"pkgdown\")'
-    deploy:
-      provider: script
-      script: Rscript -e 'pkgdown::deploy_site_github()'
-      skip_cleanup: true
-    "
-  )
-
-  use_github_pages()
-
-  invisible()
-}
