@@ -2,10 +2,9 @@
 #'
 #' Performs set up for checking the reverse dependencies of an R package, as
 #' implemented by the revdepcheck package:
-#' * Adds `revdep` directory and adds it to `.Rbuildignore`
+#' * Creates `revdep/` directory and adds it to `.Rbuildignore`
 #' * Populates `revdep/.gitignore` to prevent tracking of various revdep
 #' artefacts
-#' * Creates `revdep/email.yml` for use with `revdepcheck::revdep_email()`
 #' * Prompts user to run the checks with `revdepcheck::revdep_check()`
 #'
 #' @export
@@ -21,11 +20,6 @@ use_revdep <- function() {
     )
   )
 
-  new <- use_template(
-    "revdep-email.yml",
-    "revdep/email.yml"
-  )
-
   ui_todo("Run checks with {ui_code('revdepcheck::revdep_check(num_workers = 4)')}")
-  invisible(new)
+  invisible()
 }
