@@ -5,17 +5,18 @@
 
 #' usethis supports semantic versioning, which is described in more detail in
 #' the [version
-#' section](https://r-pkgs.org/description.html#description-version) of [R
+#' section](https://r-pkgs.org/lifecycle.html#sec-lifecycle-version-number) of [R
 #' Packages](https://r-pkgs.org). A version number breaks down like so:
 #'
-#'     <major>.<minor>.<patch>       (released version)
-#'     <major>.<minor>.<patch>.<dev> (dev version)
-#'
+#' ```
+#' <major>.<minor>.<patch>       (released version)
+#' <major>.<minor>.<patch>.<dev> (dev version)
+#' ```
 
 #' `use_version()` increments the "Version" field in `DESCRIPTION`, adds a new
-#' heading to `NEWS.md` (if it exists), and commits those changes (if package
-#' uses Git). It makes the same update to a line like `PKG_version = "x.y.z";`
-#' in `src/version.c` (if it exists).
+#' heading to `NEWS.md` (if it exists), commits those changes (if package uses
+#' Git), and optionally pushes (if safe to do so). It makes the same update to a
+#' line like `PKG_version = "x.y.z";` in `src/version.c` (if it exists).
 #'
 
 #' `use_dev_version()` increments to a development version, e.g. from 1.0.0 to
@@ -28,7 +29,7 @@
 
 #'
 #' @seealso The [version
-#'   section](https://r-pkgs.org/description.html#description-version) of [R
+#'   section](https://r-pkgs.org/lifecycle.html#sec-lifecycle-version-number) of [R
 #'   Packages](https://r-pkgs.org).
 #'
 #' @examples
@@ -45,8 +46,10 @@
 NULL
 
 #' @rdname use_version
+#' @param push If `TRUE`, also attempts to push the commits to the remote
+#'   branch.
 #' @export
-use_version <- function(which = NULL) {
+use_version <- function(which = NULL, push = FALSE) {
   if (is.null(which) && !is_interactive()) {
     return(invisible(FALSE))
   }
@@ -61,7 +64,7 @@ use_version <- function(which = NULL) {
     return(invisible(FALSE))
   }
 
-  use_description_field("Version", new_ver, overwrite = TRUE)
+  proj_desc_field_update("Version", new_ver, overwrite = TRUE)
   if (names(new_ver) == "dev") {
     use_news_heading("(development version)")
   } else {
@@ -73,48 +76,54 @@ use_version <- function(which = NULL) {
   git_ask_commit(
     glue("Increment version number to {new_ver}"),
     untracked = TRUE,
+    push = push,
     paths = c("DESCRIPTION", "NEWS.md", path("src", "version.c"))
   )
+
   invisible(TRUE)
 }
 
 #' @rdname use_version
 #' @export
-use_dev_version <- function() {
+use_dev_version <- function(push = FALSE) {
   check_is_package("use_dev_version()")
-  ver <- desc::desc_get_version(proj_get())
-  if (length(unlist(ver)) > 3) {
+  if (is_dev_version()) {
     return(invisible())
   }
-  use_version(which = "dev")
+  use_version(which = "dev", push = push)
 }
 
 choose_version <- function(message, which = NULL) {
-  ver <- desc::desc_get_version(proj_get())
-  versions <- bump_version(ver)
+  versions <- bump_version()
+  rtypes <- names(versions)
+  which <- which %||% rtypes
+  which <- arg_match(which, values = rtypes, multiple = TRUE)
+  versions <- versions[which]
 
-  if (is.null(which)) {
-    choice <- utils::menu(
-      choices = glue(
-        "{format(names(versions), justify = 'right')} --> {versions}"
-      ),
-      title = glue(
-        "Current version is {ver}.\n",
-        "{message} (0 to exit)"
-      )
-    )
-    if (choice == 0) {
-      return(invisible())
-    } else {
-      which <- names(versions)[choice]
-    }
+  if (length(versions) == 1) {
+    return(versions)
   }
 
-  which <- match.arg(which, c("major", "minor", "patch", "dev"))
-  versions[which]
+  choice <- utils::menu(
+    choices = glue(
+      "{format(names(versions), justify = 'right')} --> {versions}"
+    ),
+    title = glue(
+      "Current version is {proj_version()}.\n",
+      "{message} (0 to exit)"
+    )
+  )
+
+  if (choice == 0) {
+    invisible()
+  } else {
+    # Not using `[[` even though there is only 1 `choice`,
+    # because that removes the names from `versions`
+    versions[choice]
+  }
 }
 
-bump_version <- function(ver) {
+bump_version <- function(ver = proj_version()) {
   bumps <- c("major", "minor", "patch", "dev")
   vapply(bumps, bump_, character(1), ver = ver)
 }
@@ -142,3 +151,8 @@ use_c_version <- function(ver) {
 
   write_utf8(version_path, lines)
 }
+
+is_dev_version <- function(version = proj_version()) {
+  ver <- package_version(version)
+  length(unlist(ver)) > 3
+}
