@@ -1,13 +1,13 @@
 test_that("use_github_action() allows for custom urls", {
-  skip_on_cran()
   skip_if_no_git_user()
-  skip_if_offline()
+  skip_if_offline("github.com")
 
   local_interactive(FALSE)
 
   create_local_package()
   use_git()
   use_git_remote(name = "origin", url = "https://github.com/OWNER/REPO")
+  use_readme_md()
 
   withr::local_options(usethis.quiet = FALSE)
   expect_snapshot(
@@ -18,13 +18,16 @@ test_that("use_github_action() allows for custom urls", {
   )
   expect_proj_dir(".github")
   expect_proj_dir(".github/workflows")
-  expect_proj_file(".github/workflows/check-full.yaml")
+  expect_proj_file(".github/workflows/R-CMD-check.yaml")
+})
+
+test_that("use_github_action() still errors in non-interactive environment", {
+  expect_snapshot(use_github_action(), error = TRUE)
 })
 
 test_that("use_github_action() appends yaml in name if missing", {
-  skip_on_cran()
   skip_if_no_git_user()
-  skip_if_offline()
+  skip_if_offline("github.com")
   local_interactive(FALSE)
 
   create_local_package()
@@ -35,13 +38,12 @@ test_that("use_github_action() appends yaml in name if missing", {
 
   expect_proj_dir(".github")
   expect_proj_dir(".github/workflows")
-  expect_proj_file(".github/workflows/check-full.yaml")
+  expect_proj_file(".github/workflows/R-CMD-check.yaml")
 })
 
 test_that("use_github_action() accepts a ref", {
-  skip_on_cran()
   skip_if_no_git_user()
-  skip_if_offline()
+  skip_if_offline("github.com")
   local_interactive(FALSE)
 
   create_local_package()
@@ -50,24 +52,27 @@ test_that("use_github_action() accepts a ref", {
 
   use_github_action("check-full", ref = "v1")
   expect_snapshot(
-    read_utf8(proj_path(".github/workflows/check-full.yaml"), n = 1)
+    read_utf8(proj_path(".github/workflows/R-CMD-check.yaml"), n = 1)
   )
 })
 
-test_that("uses_github_actions() reports usage of GitHub Actions", {
-  skip_on_cran()
+test_that("uses_github_action() reports usage of GitHub Actions", {
   skip_if_no_git_user()
-  skip_if_offline()
+  skip_if_offline("github.com")
   local_interactive(FALSE)
 
   create_local_package()
   expect_false(uses_github_actions())
+
   use_git()
   use_git_remote(name = "origin", url = "https://github.com/OWNER/REPO")
-  with_mock(
-    use_github_actions_badge = function(name, repo_spec) NULL,
-    use_github_actions()
+
+  local_mocked_bindings(
+    use_github_actions_badge = function(name, repo_spec) NULL
   )
+
+  use_github_action("check-standard")
+
   expect_true(uses_github_actions())
 })
 
@@ -81,10 +86,9 @@ test_that("check_uses_github_actions() can throw error", {
   )
 })
 
-test_that("use_github_actions() configures the basic check action", {
-  skip_on_cran()
+test_that("use_github_action() accepts a name", {
   skip_if_no_git_user()
-  skip_if_offline()
+  skip_if_offline("github.com")
   local_interactive(FALSE)
 
   create_local_package()
@@ -92,7 +96,7 @@ test_that("use_github_actions() configures the basic check action", {
   use_git_remote(name = "origin", url = "https://github.com/OWNER/REPO")
   use_readme_md()
 
-  use_github_actions()
+  use_github_action("check-release")
 
   expect_proj_dir(".github")
   expect_proj_dir(".github/workflows")
@@ -110,9 +114,8 @@ test_that("use_github_actions() configures the basic check action", {
 })
 
 test_that("use_tidy_github_actions() configures the full check and pr commands", {
-  skip_on_cran()
   skip_if_no_git_user()
-  skip_if_offline()
+  skip_if_offline("github.com")
   local_interactive(FALSE)
 
   create_local_package()
