@@ -1,11 +1,12 @@
 test_that("use_lifecycle() imports badges", {
-  create_local_package(fs::path_temp("test_lifecycle"))
+  create_local_package()
   use_package_doc()
   withr::local_options(usethis.quiet = FALSE)
 
-  expect_snapshot({
-    use_lifecycle()
-  })
+  expect_snapshot(
+    use_lifecycle(),
+    transform = scrub_testpkg
+  )
 
   expect_proj_file("man", "figures", "lifecycle-stable.svg")
   expect_equal(roxygen_ns_show(), "#' @importFrom lifecycle deprecated")
